from setuptools import setup,find_packages

setup(
    name='xiaogang',
    version='1.0.3',
    author='yangXX',
    author_email='75281291@qq.com',

    description='This software is some simple search',

    url = 'https://gitee.com/yang-xiao-gang/p9-xiaogang',

    packages=find_packages()
)